﻿using System.Windows;
using Stimulsoft.Report;
using System.Printing;
using System.Linq;
using System.IO;
using Stimulsoft.Report.Dictionary;
using System.Collections.Generic;
using System;

namespace PrinterProblem
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        StiReport report;
        string[] months = { "Jan", "Feb", "Mar", "Apr", "May", "Jun" , "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" };
        string selectedPrinter;

        public MainWindow()
        {
            InitializeComponent();
            Loaded += MainWindow_Loaded;
        }

        void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            LocalPrintServer printServer = new LocalPrintServer();
            var printers = printServer.GetPrintQueues(new[] { EnumeratedPrintQueueTypes.Local, EnumeratedPrintQueueTypes.Connections });
            foreach (var printer in printers.Select(d => d.FullName).ToList())
            {
                if (printer.Equals(printServer.DefaultPrintQueue.FullName)) cbxPrinters.Items.Insert(0, printer);
                else cbxPrinters.Items.Add(printer);
            }
            cbxPrinters.SelectedItem = cbxPrinters.Items[0];

            InitReport();
            PrepareData();
        }

        private void InitReport()
        {
            report = new StiReport();
            report.Load("Report.mrt");
            report["MarginesGorny"] = 1;
            report["MarginesDolny"] = 1;
            report["NaglowekRaportu"] = "Report header";
            report["PodpisFirmowy"] = "Company signature";
            report["StopkaRaportu"] = "Report footer";
            report["PokazStopkeRaportu"] = true;
            report["DataNaWydruku"] = DateTime.Now.Date;
            report["TytulDokumentu"] = "Calendar";
        }
        private void PrepareData()
        {
            var calendar = new Calendar();
            calendar.FromDate = new DateTime(2015, 8, 10);
            calendar.ToDate = new DateTime(2015, 8, 23);
            calendar.Days = new List<Day>();
            var date = calendar.FromDate;
            while (date <= calendar.ToDate)
            {
                var day = new Day
                    {
                        Date = date,
                        DisplayedDate = date.Day + " " + months[date.Month - 1],
                        Events = new List<CalendarEvent>()
                    };
                for (int i = 0; i < 9; i++)
                    day.Events.Add(new CalendarEvent { FullDay = true });

                calendar.Days.Add(day);
                date = date.AddDays(1);
            }
            PrepareEvents(calendar);

            report.RegBusinessObject("Calendar", calendar);
            report.RegBusinessObject("DaysOfTheWeek", new[] {"Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun" });
        }
        private void PrepareEvents(Calendar calendar)
        {
            var day = calendar.Days.FirstOrDefault(d => d.DisplayedDate.Equals("20 Aug"));
            day.Events.Clear();
            day.Events.Add(CreateEvent("Daily meeting", new DateTime(2015, 8, 20, 8, 15, 0), new DateTime(2015, 8, 20, 8, 29, 0)));
            day.Events.Add(CreateEvent("Product presentation", new DateTime(2015, 8, 20, 9, 0, 0), new DateTime(2015, 8, 20, 10, 30, 0)));
            day.Events.Add(CreateEvent("Send offer", new DateTime(2015, 8, 20, 10, 0, 0), new DateTime(2015, 8, 20, 10, 45, 0)));
            day.Events.Add(CreateEvent("Long task", new DateTime(2015, 8, 20, 10, 17, 0), new DateTime(2015, 8, 24, 10, 17, 0)));
            day.Events.Add(CreateEvent("Short task", new DateTime(2015, 8, 20, 10, 48, 0), new DateTime(2015, 8, 20, 11, 48, 0)));
            day.Events.Add(CreateEvent("Meeting", new DateTime(2015, 8, 20, 11, 30, 0), new DateTime(2015, 8, 20, 11, 45, 0)));

            day = calendar.Days.FirstOrDefault(d => d.DisplayedDate.Equals("21 Aug"));
            day.Events.Clear();
            day.Events.Add(CreateEvent("Long task", new DateTime(2015, 8, 20, 10, 17, 0), new DateTime(2015, 8, 24, 10, 17, 0), true));
            day.Events.Add(CreateEvent("Daily meeting", new DateTime(2015, 8, 21, 8, 15, 0), new DateTime(2015, 8, 21, 8, 29, 0)));
            day.Events.Add(CreateEvent("Task", new DateTime(2015, 8, 21, 10, 15, 0), new DateTime(2015, 8, 21, 11, 15, 0)));
            day.Events.Add(CreateEvent("Task 2", new DateTime(2015, 8, 21, 10, 15, 0), new DateTime(2015, 8, 21, 11, 15, 0)));
            day.Events.Add(CreateEvent("Task 3", new DateTime(2015, 8, 21, 10, 15, 0), new DateTime(2015, 8, 21, 11, 15, 0)));
            day.Events.Add(CreateEvent("Task 4", new DateTime(2015, 8, 21, 10, 15, 0), new DateTime(2015, 8, 21, 11, 15, 0)));
            day.Events.Add(CreateEvent("Task 5", new DateTime(2015, 8, 21, 10, 15, 0), new DateTime(2015, 8, 21, 11, 15, 0)));
            day.Events.Add(CreateEvent("Task 6", new DateTime(2015, 8, 21, 10, 15, 0), new DateTime(2015, 8, 21, 11, 15, 0)));
            day.Events.Add(CreateEvent("Task 7", new DateTime(2015, 8, 21, 10, 15, 0), new DateTime(2015, 8, 21, 11, 15, 0)));
            day.Events.Add(CreateEvent("Task 8", new DateTime(2015, 8, 21, 10, 15, 0), new DateTime(2015, 8, 21, 11, 15, 0)));
            day.Events.Add(CreateEvent("Weekly report", new DateTime(2015, 8, 21, 14, 30, 0), new DateTime(2015, 8, 21, 15, 0, 0)));

            day = calendar.Days.FirstOrDefault(d => d.DisplayedDate.Equals("22 Aug"));
            day.Events.Clear();
            day.Events.Add(CreateEvent("Long task", new DateTime(2015, 8, 20, 10, 17, 0), new DateTime(2015, 8, 24, 10, 17, 0), true));
            day.Events.Add(CreateEvent("Phone call", new DateTime(2015, 8, 22, 8, 15, 0), new DateTime(2015, 8, 22, 8, 29, 0)));
            day.Events.Add(CreateEvent("Task", new DateTime(2015, 8, 22, 10, 15, 0), new DateTime(2015, 8, 22, 11, 15, 0)));

            day = calendar.Days.FirstOrDefault(d => d.DisplayedDate.Equals("23 Aug"));
            day.Events.Clear();
            day.Events.Add(CreateEvent("Long task", new DateTime(2015, 8, 20, 10, 17, 0), new DateTime(2015, 8, 24, 10, 17, 0), true));
        }
        private CalendarEvent CreateEvent(string description, DateTime fromDate, DateTime toDate, bool fullDay = false)
        {
            return new CalendarEvent
                {
                    Description = description,
                    FromDate = fromDate,
                    FullDay = fullDay,
                    ToDate = toDate
                };
        }

        private void Print_Click(object sender, RoutedEventArgs e)
        {
            var printTicket = new PrintTicket
            {
                CopyCount = 1
            };
            report.PrintWithWpf(printTicket, false, -1, -1, -1, selectedPrinter);
        }

        private void cbxPrinters_SelectionChanged(object sender, System.Windows.Controls.SelectionChangedEventArgs e)
        {
            selectedPrinter = cbxPrinters.SelectedItem as string;
        }
    }
}
